module Rex
  module Book
    # Trade Tracker implemented as a simple ring buffer
    class TradeTracker
      include Enumerable
      DEFAULT_TRADE_HISTORY_LIMIT = 200

      attr_reader :trades

      def initialize(limit: DEFAULT_TRADE_HISTORY_LIMIT)
        @limit = limit
        @trades = Array.new(limit)
        @current_id = -1
      end

      def add(trade)
        @current_id += 1
        idx = (@current_id % @limit)
        @trades[idx] = trade
      end

      def each(&block)
        (([@current_id - @limit, 0].max)..@current_id ).each do |id|
          yield @trades[id % @limit]
        end
      end
    end
  end
end
